@@ -3,9 +3,11 @@ Main interface for imagebuilder service type definitions.
 
 Usage::
 
-    from mypy_boto3.imagebuilder.type_defs import AmiDistributionConfigurationTypeDef
+    ```python
+    from mypy_boto3_imagebuilder.type_defs import AmiDistributionConfigurationTypeDef
 
     data: AmiDistributionConfigurationTypeDef = {...}
+    ```
 """
 import sys
 from typing import Dict, List
